@@ -42,7 +42,16 @@ class ActivityWorker(Actor):
         :param  details: provided details about cancel
         :type   details: string
         """
-        return self.connection.respond_activity_task_canceled(task_token)
+        try:
+            return self.connection.respond_activity_task_canceled(task_token)
+        except SWFResponseError as e:
+            if e.error_code == 'UnknownResourceFault':
+                raise DoesNotExistError(
+                    "Unable to cancel activity task with token: {}.\n".format(task_token),
+                    e.body['message']
+                )
+
+                raise ResponseError(e.body['message'])
 
     def complete(self, task_token, result=None):
         """Responds to ``swf` that the activity task is completed
@@ -53,10 +62,19 @@ class ActivityWorker(Actor):
         :param  result: The result of the activity task.
         :type   result: string
         """
-        return self.connection.respond_activity_task_completed(
-            task_token,
-            result
-        )
+        try:
+            return self.connection.respond_activity_task_completed(
+                task_token,
+                result
+            )
+        except SWFResponseError as e:
+            if e.error_code == 'UnknownResourceFault':
+                raise DoesNotExistError(
+                    "Unable to complete activity task with token: {}.\n".format(task_token),
+                    e.body['message']
+                )
+
+            raise ResponseError(e.body['message'])
 
     def fail(self, task_token, details=None, reason=None):
         """Replies to ``swf`` that the activity task failed
@@ -70,11 +88,20 @@ class ActivityWorker(Actor):
         :param  reason: Description of the error that may assist in diagnostics
         :type   reason: string
         """
-        return self.connection.respond_activity_task_failed(
-            task_token,
-            details,
-            reason
-        )
+        try:
+            return self.connection.respond_activity_task_failed(
+                task_token,
+                details,
+                reason
+            )
+        except SWFResponseError as e:
+            if e.error_code == 'UnknownResourceFault':
+                raise DoesNotExistError(
+                    "Unable to fail activity task with token: {}.\n".format(task_token),
+                    e.body['message']
+                )
+
+            raise ResponseError(e.body['message'])
 
     def heartbeat(self, task_token, details=None):
         """Records activity task heartbeat
@@ -85,10 +112,19 @@ class ActivityWorker(Actor):
         :param  details: provided details about cancel
         :type   details: string
         """
-        return self.connection.record_activity_task_heartbeat(
-            task_token,
-            details
-        )
+        try:
+            return self.connection.record_activity_task_heartbeat(
+                task_token,
+                details
+            )
+        except SWFResponseError as e:
+            if e.error_code == 'UnknownResourceFault':
+                raise DoesNotExistError(
+                    "Unable to send activity task {} heartbeat.\n".format(task_token),
+                    e.body['message']
+                )
+
+            raise ResponseError(e.body['message'])
 
     def poll(self, task_list=None, identity=None):
         """Polls for an activity task to process from current
@@ -115,11 +151,20 @@ class ActivityWorker(Actor):
         task_list = task_list or self.task_list
         identity = identity or self.identity
 
-        polled_activity_data = self.connection.poll_for_activity_task(
-            self.domain.name,
-            task_list,
-            identity=identity
-        )
+        try:
+            polled_activity_data = self.connection.poll_for_activity_task(
+                self.domain.name,
+                task_list,
+                identity=identity
+            )
+        except SWFResponseError as e:
+            if e.error_code == 'UnknownResourceFault':
+                raise DoesNotExistError(
+                    "Unable to poll activity task.\n",
+                    e.body['message']
+                )
+
+            raise ResponseError(e.body['message'])
 
         if not 'taskToken' in polled_activity_data:
             raise PollTimeout("Activity Worker poll timed out")
